{% load i18n wagtailroutablepage_tags %}

<ul>
    {% for tag in tags %}
        <li class="tag">
            <a href="{% routablepageurl blog_page "entries_by_tag" tag.slug %}">{{ tag }}</a>
        </li>
    {% empty %}
        {% trans 'No tags yet' %}
    {% endfor %}
</ul>